@@ -7,31 +7,12 @@ use File::Path qw();
 use Fatal qw(chdir open);
 use Test::Differences;
 use File::Find;
-use ExtUtils::Command qw();
-use File::Spec;
-use Module::Build::ConfigData;
-use Config;
 
 our @EXPORT = qw(run_build_pl run_build clean_install check_tree
-                 set_module_dir touch_file if_has_html if_has_man
-                 if_has_man_path %Config);
+                 set_module_dir);
 
 my $module_dir = 'Call set_module_dir()';
 my $support_executable_bit = 0;
-my $support_html =    Module::Build::ConfigData->feature( 'HTML_support' )
-                   && defined $Config{installhtmldir}
-                   && length $Config{installhtmldir};
-my $support_man =    Module::Build::ConfigData->feature( 'manpage_support' )
-                  && defined $Config{man3ext}
-                  && length $Config{man3ext};
-my $has_man_path =    (    defined $Config{installman3dir}
-                        && length $Config{installman3dir} )
-                   || (    defined $Config{installsiteman3dir}
-                        && length $Config{installsiteman3dir} );
-
-sub if_has_html { $support_html ? @_ : () }
-sub if_has_man  { $support_man  ? @_ : () }
-sub if_has_man_path { $support_man && $has_man_path? @_ : () }
 
 sub set_module_dir {
     $module_dir = $_[0];
@@ -40,8 +21,6 @@ sub set_module_dir {
 sub clean_install {
     File::Path::rmtree( 't/test_install' );
     File::Path::rmtree( 't/Foo/blib' );
-    File::Path::rmtree( 'archive' );
-    File::Path::rmtree( 'unpack' );
     File::Path::mkpath( 't/test_install' );
 
     open my $fh, '>', 't/test_install/is_x';
@@ -63,7 +42,6 @@ sub _run {
 
 sub run_build_pl {
     my( @args ) = @_;
-    local $ENV{PERL_MB_OPT};
     chdir $module_dir;
     _run( 'Build.PL', @args );
     chdir '../..';
@@ -71,7 +49,6 @@ sub run_build_pl {
 
 sub run_build {
     my( @args ) = @_;
-    local $ENV{PERL_MB_OPT};
     chdir $module_dir;
     _run( 'Build', @args );
     chdir '../..';
@@ -82,8 +59,7 @@ sub check_tree {
     my $found = {};
     my $wanted = sub {
         return unless -f $_;
-        my $canon_name = File::Spec->canonpath( $File::Find::name );
-        $found->{$canon_name} =
+        $found->{$File::Find::name} =
           { executable => -x $_ ? 1 : 0 };
     };
     find( $wanted, $directory );
@@ -102,9 +78,4 @@ sub check_tree {
     eq_or_diff( $found, $fixed_tree );
 }
 
-sub touch_file {
-    local @ARGV = $_[0];
-    ExtUtils::Command::touch();
-}
-
 1;
